OC.L10N.register(
    "core",
    {
    "Please select a file." : "请选择一个文件。",
    "File is too big" : "文件太大",
    "The selected file is not an image." : "所选文件不是一张图片。",
    "The selected file cannot be read." : "无法读取所选文件。",
    "The file was uploaded" : "文件已上传 ",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传的文件超过了 php.ini 中的 upload_max_filesize 指令",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件超过了 HTML 表单中指定的 MAX_FILE_SIZE 指令",
    "The file was only partially uploaded" : "文件仅部分上传 ",
    "No file was uploaded" : "没有文件被上传 ",
    "Missing a temporary folder" : "缺少临时文件夹 ",
    "Could not write file to disk" : "无法将文件写入磁盘",
    "A PHP extension stopped the file upload" : "PHP 扩展程序终止了文件上传",
    "Invalid file provided" : "提供的文件无效",
    "No image or file provided" : "没有提供图片或文件",
    "Unknown filetype" : "未知的文件类型",
    "An error occurred. Please contact your admin." : "发生了错误，请联系管理员。",
    "Invalid image" : "无效的图片",
    "No temporary profile picture available, try again" : "没有临时个人页图片可用，请重试",
    "No crop data provided" : "没有提供剪裁数据",
    "No valid crop data provided" : "没有提供有效的裁剪数据",
    "Crop is not square" : "裁剪的不是正方形",
    "State token does not match" : "状态令牌无法匹配",
    "Invalid app password" : "无效的应用密码",
    "Could not complete login" : "无法完成登录",
    "State token missing" : "状态令牌丢失",
    "Your login token is invalid or has expired" : "你的登录 token 无效或已过期",
    "Please use original client" : "请使用原始客户端",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "这个 Nextcloud 的社区版本不受支持，推送通知功能受限。",
    "Login" : "登录",
    "Unsupported email length (>255)" : "不支持的电子邮箱长度（>255）",
    "Password reset is disabled" : "重置密码已禁用",
    "Could not reset password because the token is expired" : "无法重设密码，因为令牌已过期",
    "Could not reset password because the token is invalid" : "无法重置密码，因为 token 无效",
    "Password is too long. Maximum allowed length is 469 characters." : "密码太长。最大允许长度为 469 个字符。",
    "%s password reset" : "重置 %s 的密码",
    "Password reset" : "重置密码",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "点击下方按钮来重置您的密码。如果您并没有请求密码重置，请忽略这封邮件。",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "点击下方链接重置您的密码。如果您没有请求重置密码，请忽略本邮件。",
    "Reset your password" : "重置您的密码",
    "The given provider is not available" : "指定提供者不可用",
    "Task not found" : "找不到任务",
    "Internal error" : "内部错误",
    "Not found" : "未找到",
    "Node is locked" : "节点已锁定",
    "Bad request" : "请求错误",
    "Requested task type does not exist" : "请求的任务类型不存在",
    "Necessary language model provider is not available" : "无必要的语言模型提供程序",
    "No text to image provider is available" : "没有可用的文字转图片提供者",
    "Image not found" : "未找到图片",
    "No translation provider available" : "没有可用的翻译提供程序",
    "Could not detect language" : "无法检测语言",
    "Unable to translate" : "无法翻译",
    "[%d / %d]: %s" : "[%d / %d]：%s",
    "Repair step:" : "修复日志 步骤：",
    "Repair info:" : "修复 信息：",
    "Repair warning:" : "修复 警告：",
    "Repair error:" : "修复 错误：",
    "Nextcloud Server" : "Nextcloud 服务器",
    "Some of your link shares have been removed" : "您的一些链接共享已被移除",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "由于一个安全缺陷，我们必须移除您的部分链接共享。更多信息请查看此链接。",
    "The account limit of this instance is reached." : "已达到这个实例的最大账号上限。",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "在支持应用中输入你的订阅秘钥以拓展账号数量限制。这也确保您可以体验到 Nextcloud Enterprise 额外优势，强烈建议在公司应用场景中启用订阅。",
    "Learn more ↗" : "了解更多 ↗",
    "Preparing update" : "正在准备更新",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "请使用命令行更新程序，因为通过浏览器更新在您的config.php中被禁用。",
    "Turned on maintenance mode" : "启用维护模式",
    "Turned off maintenance mode" : "关闭维护模式",
    "Maintenance mode is kept active" : "维护模式已启用",
    "Updating database schema" : "正在更新数据库结构",
    "Updated database" : "数据库已更新",
    "Update app \"%s\" from App Store" : "从应用商店更新应用“%s”",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "检查 %s 的数据库结构是否可以更新（这可能需要很长的时间，取决于数据库大小）",
    "Updated \"%1$s\" to %2$s" : "已经从“%1$s”更新到 %2$s",
    "Set log level to debug" : "设置日志级别为 调试",
    "Reset log level" : "重置日志级别",
    "Starting code integrity check" : "开始代码完整性检查",
    "Finished code integrity check" : "代码完整性检查已完成",
    "%s (incompatible)" : "%s （不兼容）",
    "The following apps have been disabled: %s" : "以下应用已被禁用：%s",
    "Already up to date" : "已经是最新版本",
    "Windows Command Script" : "Windows 命令脚本",
    "Electronic book document" : "电子书文档",
    "TrueType Font Collection" : "TrueType 字体集",
    "Web Open Font Format" : "Web 开放字体格式",
    "GPX geographic data" : "GPX 地理数据",
    "Gzip archive" : "Gzip 归档文件",
    "Adobe Illustrator document" : "Adobe Illustrator 文档",
    "Java source code" : "Java 源代码",
    "JavaScript source code" : "JavaScript 源代码",
    "JSON document" : "JSON 文档",
    "Microsoft Access database" : "Microsoft Access 数据库",
    "Microsoft OneNote document" : "Microsoft OneNote 文档",
    "Microsoft Word document" : "Microsoft Word 文档",
    "Unknown" : "未知",
    "PDF document" : "PDF 文档",
    "PostScript document" : "PostScript 文档",
    "RSS summary" : "RSS 摘要",
    "Android package" : "Android 软件包",
    "KML geographic data" : "KML 地理数据",
    "KML geographic compressed data" : "KML 地理压缩数据",
    "Lotus Word Pro document" : "Lotus Word Pro document文档",
    "Excel spreadsheet" : "Excel 电子表格",
    "Excel add-in" : "Excel 插件",
    "Excel 2007 binary spreadsheet" : "Excel 2007 二进制电子表格",
    "Excel spreadsheet template" : "Excel 电子表格模板",
    "Outlook Message" : "Outlook 邮件",
    "PowerPoint presentation" : "PowerPoint 演示文稿",
    "PowerPoint add-in" : "PowerPoint 插件",
    "PowerPoint presentation template" : "PowerPoint 演示文稿模板",
    "Word document" : "Word 文档",
    "ODF formula" : "ODF 公式",
    "ODG drawing" : "ODG 绘图",
    "ODG drawing (Flat XML)" : "ODG 绘图（Flat XML）",
    "ODG template" : "ODG 模板",
    "ODP presentation" : "ODP 演示文稿",
    "ODP presentation (Flat XML)" : "ODP 演示文稿（Flat XML）",
    "ODP template" : "ODP 模板",
    "ODS spreadsheet" : "ODS 电子表格",
    "ODS spreadsheet (Flat XML)" : "ODS 电子表格（Flat XML）",
    "ODS template" : "ODS 模板",
    "ODT document" : "ODT 文档",
    "ODT document (Flat XML)" : "ODT 文档（Flat XML）",
    "ODT template" : "ODT 模板",
    "PowerPoint 2007 presentation" : "PowerPoint 2007 演示文稿",
    "PowerPoint 2007 show" : "PowerPoint 2007 放映",
    "PowerPoint 2007 presentation template" : "PowerPoint 2007 演示文稿模板",
    "Excel 2007 spreadsheet" : "Excel 2007 电子表格",
    "Excel 2007 spreadsheet template" : "Excel 2007 电子表格模板",
    "Word 2007 document" : "Word 2007 文档",
    "Word 2007 document template" : "Word 2007 文档模板",
    "Microsoft Visio document" : "Microsoft Visio 文档",
    "WordPerfect document" : "WordPerfect 文档",
    "7-zip archive" : "7-zip 归档文件",
    "Blender scene" : "Blender 场景",
    "Bzip2 archive" : "Bzip2 归档文件",
    "Debian package" : "Debian 软件包",
    "FictionBook document" : "FictionBook 文档",
    "Unknown font" : "未知字体",
    "Krita document" : "Krita 文档",
    "Mobipocket e-book" : "Mobipocket 电子书",
    "Windows Installer package" : "Windows Installer 安装包",
    "Perl script" : "Perl 脚本",
    "PHP script" : "PHP 脚本",
    "Tar archive" : "Tar 归档文件",
    "XML document" : "XML 文档",
    "YAML document" : "YAML 文档",
    "Zip archive" : "Zip 归档文件",
    "Zstandard archive" : "Zstandard 归档文件",
    "AAC audio" : "AAC 音频",
    "FLAC audio" : "FLAC 音频",
    "MPEG-4 audio" : "MPEG-4 音频",
    "MP3 audio" : "MP3 音频",
    "Ogg audio" : "Ogg 音频",
    "RIFF/WAVe standard Audio" : "RIFF/WAVe 标准音频",
    "WebM audio" : "WebM 音频",
    "MP3 ShoutCast playlist" : "MP3 ShoutCast 播放列表",
    "Windows BMP image" : "Windows BMP 图片",
    "Better Portable Graphics image" : "Better Portable Graphics 图片",
    "EMF image" : "EMF 图片",
    "GIF image" : "GIF 图片",
    "HEIC image" : "HEIC 图片",
    "HEIF image" : "HEIF 图片",
    "JPEG-2000 JP2 image" : "JPEG-2000 JP2 图片",
    "JPEG image" : "JPEG 图片",
    "PNG image" : "PNG 图片",
    "SVG image" : "SVG 图片",
    "Truevision Targa image" : "Truevision Targa 图片",
    "TIFF image" : "TIFF 图片",
    "WebP image" : "WebP 图片",
    "Digital raw image" : "数字原始图像",
    "Windows Icon" : "Windows 图标",
    "Email message" : "电子邮件消息",
    "VCS/ICS calendar" : "VCS/ICS 日历",
    "CSS stylesheet" : "CSS 样式表",
    "CSV document" : "CSV 文档",
    "HTML document" : "HTML 文档",
    "Markdown document" : "Markdown 文档",
    "Org-mode file" : "Org-mode 文件",
    "Plain text document" : "纯文本文档",
    "Rich Text document" : "富文本文档",
    "Electronic business card" : "电子名片",
    "C++ source code" : "C++ 源代码",
    "LDIF address book" : "LDIF 通讯录",
    "NFO document" : "NFO 文档",
    "PHP source" : "PHP 源代码",
    "Python script" : "Python 脚本",
    "ReStructuredText document" : "ReStructuredText 文档",
    "3GPP multimedia file" : "3GPP 多媒体文件",
    "MPEG video" : "MPEG 视频",
    "DV video" : "DV 视频",
    "MPEG-2 transport stream" : "MPEG-2 传输流",
    "MPEG-4 video" : "MPEG-4 视频",
    "Ogg video" : "Ogg 视频",
    "QuickTime video" : "QuickTime 视频",
    "WebM video" : "WebM 视频",
    "Flash video" : "Flash 视频",
    "Matroska video" : "Matroska 视频",
    "Windows Media video" : "Windows 媒体视频",
    "AVI video" : "AVI 视频",
    "unknown text" : "未知文字",
    "Hello world!" : "你好，世界！",
    "sunny" : "晴",
    "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是 {weather}",
    "Hello {name}" : "您好 {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>这是您的搜索结果<script>警告（1）</script></strong>",
    "new" : "新建",
    "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些环境下离开当前页面可能会中断。",
    "Update to {version}" : "升级到 {version}",
    "An error occurred." : "发生错误。",
    "Please reload the page." : "请重新加载页面。",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "更新失败。有关此问题的更多信息请<a href=\"{url}\">查看我们的论坛帖子</a>。",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "升级失败。请将此问题报告给 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud社区</a>。",
    "Continue to {productName}" : "继续到 {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["更新成功，%n 秒后你将重定向到 {productName}。"],
    "Applications menu" : "应用程序菜单",
    "Apps" : "应用",
    "More apps" : "更多的应用程序",
    "_{count} notification_::_{count} notifications_" : ["{count} 条通知"],
    "No" : "否",
    "Yes" : "是",
    "The remote URL must include the user." : "远程 URL 必须包含用户。",
    "Invalid remote URL." : "无效远程 URL。",
    "Failed to add the public link to your Nextcloud" : "无法将公开链接添加到您的 Nextcloud",
    "Federated user" : "联合云用户",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "创建共享",
    "Direct link copied" : "直接链接已复制",
    "Please copy the link manually:" : "请手动复制链接：",
    "Custom date range" : "自定义日期范围",
    "Pick start date" : "选择起始日期",
    "Pick end date" : "选择结束日期",
    "Search in date range" : "在日期范围内进行搜索",
    "Search in current app" : "在当前应用程序中搜索",
    "Clear search" : "清除搜索",
    "Search everywhere" : "在所有位置搜索",
    "Searching …" : "正在搜索 ...",
    "Start typing to search" : "开始输入以搜索",
    "No matching results" : "无匹配结果",
    "Today" : "今日",
    "Last 7 days" : "过去 7 天",
    "Last 30 days" : "过去 30 天",
    "This year" : "今年",
    "Last year" : "去年",
    "Unified search" : "统一搜索",
    "Search apps, files, tags, messages" : "搜索应用程序、文件、标签，信息",
    "Places" : "位置",
    "Date" : "日期",
    "Search people" : "搜索用户",
    "People" : "用户",
    "Filter in current view" : "在当前视图中筛选",
    "Search connected services" : "搜索已连接的服务",
    "Results" : "结果",
    "Load more results" : "加载更多结果",
    "Search in" : "搜索",
    "Log in" : "登录",
    "Logging in …" : "正在登录……",
    "Log in to {productName}" : "登录到 {productName}",
    "Wrong login or password." : "账号或密码错误",
    "This account is disabled" : "此账号已停用",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "我们检测到你的 IP 进行了多次无效登录尝试。因此，你的下一次登录将被延迟 30 秒。",
    "Account name or email" : "账号名称或电子邮箱",
    "Account name" : "账号名称",
    "Server side authentication failed!" : "服务端身份验证失败！",
    "Please contact your administrator." : "请联系您的管理员。",
    "Session error" : "会话错误",
    "It appears your session token has expired, please refresh the page and try again." : "您的会话令牌似乎已过期，请刷新页面并重试。",
    "An internal error occurred." : "发生了内部错误。",
    "Please try again or contact your administrator." : "请重试或联系您的管理员。",
    "Password" : "密码",
    "Log in with a device" : "使用设备登录",
    "Login or email" : "账号或电子邮箱",
    "Your account is not setup for passwordless login." : "你的账号未设置无密码登录。",
    "Your connection is not secure" : "您的连接不安全",
    "Passwordless authentication is only available over a secure connection." : "无密码身份验证仅在安全连接上可用。",
    "Browser not supported" : "浏览器不受支持",
    "Passwordless authentication is not supported in your browser." : "浏览器不支持无密码验证。",
    "Reset password" : "重置密码",
    "Back to login" : "返回登录",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "如果账号存在，一封密码重置信息将会被发送至你的电子邮箱地址。如果你没有收到该邮件，请验证你的电子邮箱地址/账号拼写是否正确，或检查邮件是否被归为垃圾邮件文件夹，或请求本地管理员的帮助。",
    "Couldn't send reset email. Please contact your administrator." : "未能成功发送重置邮件，请联系管理员。",
    "Password cannot be changed. Please contact your administrator." : "无法更改密码，请联系管理员。",
    "New password" : "新密码",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "您的文件已经加密。您的密码重置后就没有任何方式能恢复您的数据了。如果您不确定，请在继续前联系您的管理员。您是否真的要继续？",
    "I know what I'm doing" : "我知道我在做什么",
    "Resetting password" : "正在重置密码",
    "Schedule work & meetings, synced with all your devices." : "安排工作和会议，并与您的所有设备同步。",
    "Keep your colleagues and friends in one place without leaking their private info." : "将您的同事和朋友放在一个地方，而不会泄漏他们的私人信息。",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "简单的电子邮箱应用与文件，联系人和日历完美集成。",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "在浏览器和移动应用中进行聊天，视频通话，屏幕共享，线上见面和网络会议。",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基于 Collabora Online 的文档、表格与演示文档。",
    "Distraction free note taking app." : "无干扰的笔记记录应用。",
    "Recommended apps" : "推荐的应用",
    "Loading apps …" : "正在加载应用…",
    "Could not fetch list of apps from the App Store." : "无法从应用商店获取应用列表",
    "App download or installation failed" : "应用下载或安装失败",
    "Cannot install this app because it is not compatible" : "无法安装此应用，因它不兼容",
    "Cannot install this app" : "无法安装此应用",
    "Skip" : "跳过",
    "Installing apps …" : "正在安装应用...",
    "Install recommended apps" : "安装推荐的应用",
    "Avatar of {displayName}" : "{displayName} 的头像",
    "Settings menu" : "设置菜单",
    "Loading your contacts …" : "正在加载您的联系人……",
    "Looking for {term} …" : "正在查找{term} ……",
    "Search contacts" : "搜索联系人",
    "Reset search" : "重置搜索",
    "Search contacts …" : "搜索联系人……",
    "Could not load your contacts" : "无法加载您的联系人",
    "No contacts found" : "无法找到联系人",
    "Show all contacts" : "显示所有联系人",
    "Install the Contacts app" : "安装联系人应用",
    "Search" : "搜索",
    "No results for {query}" : "没有 '{query}' 的相关结果",
    "Press Enter to start searching" : "按下Enter开始搜索",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["请输入 {minSearchLength} 个字符或更多字符以进行搜索"],
    "An error occurred while searching for {type}" : "搜索 {type} 时出错",
    "Search starts once you start typing and results may be reached with the arrow keys" : "一旦开始输入，搜索就会开始，你可以使用方向键切换到结果。",
    "Search for {name} only" : "仅搜索 {name}",
    "Loading more results …" : "加载更多结果...",
    "Forgot password?" : "忘记密码？",
    "Back to login form" : "回到登录表单",
    "Back" : "返回",
    "Login form is disabled." : "登录表单已禁用",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 登录表单已禁用。如果可以，请使用其他登录选项或联系你的管理人员。",
    "More actions" : "更多操作 ",
    "User menu" : "用户菜单",
    "Your guest name: {user}" : "您的访客名称：{user}",
    "You are currently not identified." : "您当前未被标识。",
    "Set public name" : "设置公开名称",
    "Change public name" : "更改公开名称",
    "Password is too weak" : "密码太弱",
    "Password is weak" : "弱密码",
    "Password is average" : "一般密码",
    "Password is strong" : "强密码",
    "Password is very strong" : "密码很强",
    "Password is extremely strong" : "密码极强",
    "Unknown password strength" : "密码强度未知",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "您的数据目录和文件可能可以从互联网访问，因为 <code>.htaccess</code> 文件不起作用。",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "有关如何正确配置服务器的信息，{linkStart}请参阅文档{linkEnd}",
    "Autoconfig file detected" : "检测到自动配置文件",
    "The setup form below is pre-filled with the values from the config file." : "下方设置表单预先填写了配置文件中的值。",
    "Security warning" : "安全警告",
    "Create administration account" : "创建管理员账号",
    "Administration account name" : "管理员账号名称",
    "Administration account password" : "管理员账号密码",
    "Storage & database" : "存储与数据库",
    "Data folder" : "数据目录",
    "Database configuration" : "数据库配置",
    "Only {firstAndOnlyDatabase} is available." : "只有 {firstAndOnlyDatabase} 可用。",
    "Install and activate additional PHP modules to choose other database types." : "安装并激活额外的 PHP 模块以选择其他数据库类型。",
    "For more details check out the documentation." : "请查阅文档获得详细信息。",
    "Performance warning" : "性能警告",
    "You chose SQLite as database." : "您选择 SQLite 作为数据库。",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 应只用于最小化和开发实例。生产环境我们推荐使用不同的数据库后端。",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "如果您使用文件同步客户端，强烈不建议使用 SQLite。",
    "Database user" : "数据库用户",
    "Database password" : "数据库密码",
    "Database name" : "数据库名",
    "Database tablespace" : "数据库表空间",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "请填写主机名称和端口号（例如，localhost:5432）。",
    "Database host" : "数据库主机",
    "localhost" : "本地主机",
    "Installing …" : "正在安装...",
    "Install" : "安装",
    "Need help?" : "需要帮助？",
    "See the documentation" : "查看文档",
    "{name} version {version} and above" : "{name} 版本 {version} 及更高",
    "This browser is not supported" : "您的浏览器不受支持！",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "您的浏览器不受支持。请升级至较新或受支持的版本。",
    "Continue with this unsupported browser" : "继续使用该过时的浏览器",
    "Supported versions" : "支持的版本",
    "Search {types} …" : "搜索 {types} …",
    "Choose {file}" : "选择 {file}",
    "Choose" : "选择",
    "Copy to {target}" : "复制到 {target}",
    "Copy" : "复制",
    "Move to {target}" : "移动到 {target}",
    "Move" : "移动",
    "OK" : "确认",
    "read-only" : "只读",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} 个文件冲突"],
    "One file conflict" : "1 个文件冲突",
    "New Files" : "新文件",
    "Already existing files" : "已经存在的文件",
    "Which files do you want to keep?" : "请选择需要保留的文件？",
    "If you select both versions, the copied file will have a number added to its name." : "如果同时选择了两个版本，副本的文件名中将会追加数字。",
    "Cancel" : "取消",
    "Continue" : "继续",
    "(all selected)" : "（选中全部）",
    "({count} selected)" : "（选择了 {count} 个）",
    "Error loading file exists template" : "加载文件存在性模板失败",
    "Saving …" : "正在保存…",
    "seconds ago" : "几秒前",
    "Connection to server lost" : "与服务器的连接断开",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在%n秒后重新加载"],
    "Add to a project" : "添加到项目",
    "Show details" : "显示详情",
    "Hide details" : "隐藏详细信息",
    "Rename project" : "重命名项目",
    "Failed to rename the project" : "无法重命名项目",
    "Failed to create a project" : "无法创建项目",
    "Failed to add the item to the project" : "无法将条目添加到项目中",
    "Connect items to a project to make them easier to find" : "将条目关联到项目以使它们更容易查找",
    "Type to search for existing projects" : "输入以搜索已有项目",
    "New in" : "新品",
    "View changelog" : "查看更新记录",
    "No action available" : "无可用操作",
    "Error fetching contact actions" : "查找联系人时出错",
    "Close \"{dialogTitle}\" dialog" : "关闭“{dialogTitle}”对话",
    "Email length is at max (255)" : "邮箱长度达到最大（255）",
    "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
    "Restricted" : "受限",
    "Invisible" : "隐藏",
    "Delete" : "删除",
    "Rename" : "重命名",
    "Collaborative tags" : "协作标签",
    "No tags found" : "标签未找到",
    "Clipboard not available, please copy manually" : "剪贴板不可用，请手动复制",
    "Personal" : "个人",
    "Accounts" : "账号",
    "Admin" : "管理",
    "Help" : "帮助",
    "Access forbidden" : "访问禁止",
    "You are not allowed to access this page." : "不允许您访问此页面。",
    "Back to %s" : "返回 %s",
    "Page not found" : "未找到页面",
    "The page could not be found on the server or you may not be allowed to view it." : "该页面在服务器上无法找到，或者您可能不被允许浏览。",
    "Too many requests" : "请求过多",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "您的网络请求过多。如果出现错误，请稍后重试或与您的管理员联系。",
    "Error" : "错误",
    "Internal Server Error" : "服务器内部错误",
    "The server was unable to complete your request." : "服务器不能完成您的请求。",
    "If this happens again, please send the technical details below to the server administrator." : "如果再次发生这种情况，请将下面的技术详细信息发送给服务器管理员。",
    "More details can be found in the server log." : "更多细节可以在服务器日志中找到。",
    "For more details see the documentation ↗." : "查阅说明文档以获得更多信息 ↗。",
    "Technical details" : "技术细节",
    "Remote Address: %s" : "远程地址：%s",
    "Request ID: %s" : "请求 ID：%s",
    "Type: %s" : "类型：%s",
    "Code: %s" : "代码：%s",
    "Message: %s" : "消息：%s",
    "File: %s" : "文件：%s",
    "Line: %s" : "行：%s",
    "Trace" : "追踪",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "看起来您正在尝试重新安装您的 Nextcloud。但您的 config 文件夹中没有 CAN_INSTALL 文件。请在您的 config 文件夹中创建 CAN_INSTALL 文件以继续。",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "无法从 config 文件夹中移除 CAN_INSTALL 文件。请手动移除此文件。",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "对于正确的操作，该应用需要使用 JavaScript。请 {linkstart}启用 JavaScript{linkend}，并重新加载页面。",
    "Skip to main content" : "跳过主内容",
    "Skip to navigation of app" : "跳过应用向导",
    "Go to %s" : "转至 %s",
    "Get your own free account" : "获取自己的免费账号",
    "Connect to your account" : "连接到您的账号",
    "Please log in before granting %1$s access to your %2$s account." : "在授权 %1$s 访问您的账号 %2$s 之前，请先登录。",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "如果您不打算设置新设备或应用程序，则有人试图欺骗您，以授予他们访问数据的权限。 在这种情况下，请勿继续操作，而应与系统管理员联系。",
    "App password" : "应用密码",
    "Grant access" : "授权访问",
    "Alternative log in using app password" : "使用应用密码进行登录",
    "Account access" : "账号访问",
    "Currently logged in as %1$s (%2$s)." : "当前正以 %1$s (%2$s) 身份登陆。",
    "You are about to grant %1$s access to your %2$s account." : "您正在授权 %1$s 访问您的账号 %2$s 。",
    "Account connected" : "账号已连接",
    "Your client should now be connected!" : "您的客户端现在应该可以连接了！",
    "You can close this window." : "您可以关闭此窗口。",
    "Previous" : "上一个",
    "This share is password-protected" : "这个共享是被密码保护的",
    "The password is wrong or expired. Please try again or request a new one." : "密码错误的或已经过期。请重试或申请一个新的。",
    "Please type in your email address to request a temporary password" : "请输入您的电子邮箱地址以申请一个临时密码",
    "Email address" : "电子邮箱地址",
    "Password sent!" : "密码已发送！",
    "You are not authorized to request a password for this share" : "您无权要求获得此共享的密码",
    "Two-factor authentication" : "两步验证",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "您的账号已启用安全增强。请选择第二种验证方式。",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "无法载入您启用的任何两步验证方法。请联系管理员。",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "已强制执行两步验证，但尚未在您的账号上对其进行配置。 请与您的管理员联系以获取帮助。",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "已强制执行两步验证，但尚未在您的账号上对其进行配置。 请继续设置两步验证。",
    "Set up two-factor authentication" : "配置两步验证",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "已强制执行两步验证，但尚未在您的账号上对其进行配置。 使用您的备用验证码之一登录或与管理员联系以获取帮助。",
    "Use backup code" : "使用备用口令",
    "Cancel login" : "取消登录",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "您的账号将获得增强的安全性。 选择要设置的提供者：",
    "Error while validating your second factor" : "验证您的第二项时出错",
    "Access through untrusted domain" : "通过不被信任的域名访问",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "请联系您的管理员。如果您就是管理员，请参照 config.sample.php 中的示例编辑 config/config.php 中的“trusted_domains”设置。",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "配置此项的详细内容请查阅 %1$s文档%2$s。",
    "App update required" : "必须的应用更新",
    "%1$s will be updated to version %2$s" : "%1$s 将被升级至版本 %2$s",
    "The following apps will be updated:" : "以下应用将被更新：",
    "These incompatible apps will be disabled:" : "下述不兼容的应用将被禁用：",
    "The theme %s has been disabled." : "%s 主题已被禁用。",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "在继续之前，请确认数据库、配置文件夹和数据文件夹已经备份。",
    "Start update" : "开始更新",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "为避免较大安装时的超时，您可以在安装目录下执行下述的命令：",
    "Detailed logs" : "详细日志",
    "Update needed" : "需要更新",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "因为你拥有超过50个账号的应用实例，请使用命令行进行更新。",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "获取更多帮助，请查看<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">文档</a>。",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "我知道继续通过 Web UI 进行更新的风险，请求超时运行，并可能导致数据丢失，但我有一个备份，并知道如何恢复。",
    "Upgrade via web on my own risk" : "通过网络升级的风险",
    "Maintenance mode" : "维护模式",
    "This %s instance is currently in maintenance mode, which may take a while." : "该实例 %s 当前处于维护模式，这将花费一些时间。",
    "This page will refresh itself when the instance is available again." : "当实例再次可用时，页面会自动刷新。",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
    "Error occurred while checking server setup" : "检查服务器设置时出错",
    "For more details see the {linkstart}documentation ↗{linkend}." : "了解更多详情，请参见{linkstart}文档 ↗{linkend}。",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "在浏览器和移动设备应用中进行聊天，视频通话，屏幕共享，线上见面和网络会议。",
    "You have not added any info yet" : "您尚未添加任何信息",
    "{user} has not added any info yet" : "{user} 尚未添加任何信息",
    "Error opening the user status modal, try hard refreshing the page" : "打开用户状态模块时出错，请努力刷新页面",
    "Edit Profile" : "编辑个人资料",
    "The headline and about sections will show up here" : "标题和关于部分将显示在此处",
    "Very weak password" : "非常弱的密码",
    "Weak password" : "弱密码",
    "So-so password" : "一般强度的密码",
    "Good password" : "较强的密码",
    "Strong password" : "强密码",
    "Profile not found" : "未找到个人资料",
    "The profile does not exist." : "个人资料不存在",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "因为 .htaccess 文件没有工作，您的数据目录和文件可从互联网被访问。",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "关于如何正确配置服务器，请参见<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">文档</a>。",
    "<strong>Create an admin account</strong>" : "<strong>创建管理员账号</strong>",
    "New admin account name" : "新管理员账号名称",
    "New admin password" : "新管理员密码",
    "Show password" : "显示密码",
    "Toggle password visibility" : "切换密码可见性",
    "Configure the database" : "配置数据库",
    "Only %s is available." : "仅 %s 可用。",
    "Database account" : "数据库账号",
    "Direct link copied to clipboard" : "直链已复制至粘贴板"
},
"nplurals=1; plural=0;");
